@@ -906,7 +906,7 @@ class AngularClientRendererTestCase(TestCase):
 
                       ngModule: ClientModule,
 
-                      providers: [{ provide: 'COSPHERE_CLIENT_CONFIG_TOKEN', useValue: config }]
+                      providers: [{ provide: 'CLIENT_CONFIG_TOKEN', useValue: config }]
 
                     };
                   }
